searchNodes=[{"doc":"A lightweight image processing module in Elixir using CImg, aimed at creating auxiliary routines for Deep Learning. Session execution Each function provided by CImg can be used alone (eager execution) or as a set of functions (session execution). EAGER execution is good for interactive work because you can see the results of your image processing immediately. But it tends to consume more memory than necessary. On the other hand, SESSION execution reduces memory consumption because after assembling the image processing sequence, it is executed all at once. To perform image processing in SESSION mode, you must assemble a image processing sequence using Elixir's pipe syntax. At the entrance of the pipe, place a function {seed} that generates a %Builder{}, then pipe in the necessary image processing {grow}, and finally place a function {crop} that executes those image processing. In this document, the following symbols indicate which category each function belongs to. {seed} - generate %Builder{} {grow} - image processing piece {crop} - execute session and get result Examples img = CImg . load ( &quot;sample.jpg&quot; ) CImg . builder ( img ) # generate %Builder{} with %CImg{} as seed image |&gt; CImg . draw_circle ( 100 , 100 , 30 , { 0 , 0 , 255 } ) # building an image processing session |&gt; CImg . draw_circle ( 150 , 200 , 40 , { 255 , 0 , 0 } ) # ... |&gt; CImg . display ( disp ) # execute above session and display result image on PC screen Data exchange with Nx It is easy to exchange %CImg{} and Nx tensors. # convert CImg image to Nx.Tensor iex&gt; img0 = CImg . load ( &quot;sample.jpg&quot; ) % CImg { { 2448 , 3264 , 1 , 3 } , handle : # Reference &lt; 0.2112145695 . 4205182979.233827 &gt; } iex&gt; tensor = CImg . to_binary ( img0 , dtype : &quot;&lt;u8&quot; ) |&gt; Nx . from_binary ( { :u , 8 } ) # convert Nx.Tensor to CImg image iex&gt; img1 = Nx . to_binary ( tensor ) |&gt; CImg . from_bin ( 2448 , 3264 , 1 , 3 , &quot;&lt;u8&quot; )","ref":"CImg.html","title":"CImg","type":"module"},{"doc":"{grow} Append image. Parameters img - %CImg{} or %Builder{} img2 - %CImg{}, append image axis - append on axis: {:x, :y, :z, :c} align - Examples img = CImg . load ( &quot;sample.jpg&quot; ) twice = CImg . append ( img , img , :x )","ref":"CImg.html#append/4","title":"CImg.append/4","type":"function"},{"doc":"{grow} Blending two images. Parameters img - %CImg{} or %Builder{} object. mask - %CImg{} object. ratio - blending ratio: (1.0-ratio) img + ratio mask Examples img = CImg.blend(img_org, img_mask, 0.6)","ref":"CImg.html#blend/3","title":"CImg.blend/3","type":"function"},{"doc":"{grow} Bluring image. Parameters img - %CImg{} or %Builder{} sigma - boundary_conditions - is_gaussian - Examples img = CImg . load ( &quot;sample.jpg&quot; ) blured = CImg . blur ( img , 0.3 )","ref":"CImg.html#blur/4","title":"CImg.blur/4","type":"function"},{"doc":"{seed} Returns an empty builder for recording image processing scripts. Parameters None. Examples # build a script script = CImg . builder ( ) |&gt; CImg . gray ( ) |&gt; CImg . resize ( { 256 , 256 } ) # apply the script to an image. seed = CImg . load ( &quot;sample.jpg&quot; ) result = CImg . run ( script , seed )","ref":"CImg.html#builder/0","title":"CImg.builder/0","type":"function"},{"doc":"{seed} Returns a builder with an existing %CImg{} as the seed image. Parameters img - %CImg{} Examples cimg = CImg . load ( &quot;sample.jpg&quot; ) result = CImg . builder ( cimg ) # create %Builder{} has cimg |&gt; CImg . draw_circle ( 100 , 100 , 30 , { 0 , 255 , 0 } ) |&gt; CImg . run ( )","ref":"CImg.html#builder/1","title":"CImg.builder/1","type":"function"},{"doc":"{seed} Returns a builder that uses an image read from the file as the seed image. Parameters atom - image file format: :jpeg or :png fname - file name Examples result = CImg . builder ( :jpeg , &quot;sample.jpg&quot; ) |&gt; CImg . draw_circle ( 100 , 100 , 30 , { 0 , 255 , 0 } ) |&gt; CImg . run ( )","ref":"CImg.html#builder/2","title":"CImg.builder/2","type":"function"},{"doc":"{seed} Returns a builder whose seed image is an image of shape [x,y,z,c] filled with the value val . Parameters x,y,z,c - shape of image val - filling value Examples res = CImg . builder ( 640 , 480 , 1 , 3 , 64 ) |&gt; CImg . draw_circle ( 100 , 100 , 30 , { 0 , 255 , 0 } ) |&gt; CImg . run ( )","ref":"CImg.html#builder/5","title":"CImg.builder/5","type":"function"},{"doc":"{seed} Returns a builder that takes as seed image a binary - shape[], dtype - converted to an image Parameters bin - binary x,y,z,c - shape of the image represented by bin opts - convertion options { :dtype, xxx } - convert data type to pixel. available: &quot;&lt;f4&quot;/32-bit-float, &quot;&lt;u1&quot;/8bit-unsigned-char { :range, {lo, hi} } - convert range lo..hi to 0..255. default range: {0.0, 1.0} { :gauss, {{mu-R,sigma-R},{mu-G,sigma-G},{mu-B,sigma-B}} } - inverse normalization by Gaussian distribution. :nchw - transform axes NCHW to NHWC. :bgt - convert color BGR -&gt; RGB. Examples result = CImg . builder ( bin 640 , 480 , 1 , 3 , dtype : &quot;&lt;f4&quot; ) |&gt; CImg . draw_circle ( 100 , 100 , 30 , { 0 , 255 , 0 } ) |&gt; CImg . run ( )","ref":"CImg.html#builder/6","title":"CImg.builder/6","type":"function"},{"doc":"{grow} Booking to clear the image. Parameters builder - %Builder{}. Examples result = CImg . builder ( :file , &quot;sample.jpg&quot; ) |&gt; CImg . clear ( ) |&gt; CImg . run ( )","ref":"CImg.html#clear/1","title":"CImg.clear/1","type":"function"},{"doc":"{grow} Create color mapped image by lut. Parameters img - %CImg{} or %Builder{} lut - color map. build-in or user defined. build-in map: {:default, :lines, :hot, :cool, :jet} user defined: list of color tupple, [{0,0,0},{10,8,9},{22,15,24}...]. boundary - handling the pixel value outside the color map range. 0 - set to zero value. 1 - 2 - repeat from the beginning of the color map. 3 - repeat while wrapping the color map. Examples gray = CImg . load ( &quot;sample.jpg&quot; ) |&gt; CImg . gray ( ) jet = CImg . color_mapping ( gray , :jet ) # heat-map coloring. custom = CImg . color_mapping ( gray , [ { 0 , 0 , 0 } , { 10 , 8 , 9 } , { 22 , 15 , 24 } ] , 2 ) # custom coloring.","ref":"CImg.html#color_mapping/3","title":"CImg.color_mapping/3","type":"function"},{"doc":"Create image{x,y,z,c} filled val . Parameters x,y,z,c - image's x-size, y-size, z-size and spectrum. val - filling value. Examples img = CImg . create ( 200 , 100 , 1 , 3 , 127 )","ref":"CImg.html#create/5","title":"CImg.create/5","type":"function"},{"doc":"{crop} Display the image on the CImgDisplay object. Parameters img - %CImg{} or %Builder{} display - CImgDisplay object Examples CImg . display ( cimg ) CImg . builder ( cimg ) |&gt; CImg . draw_circle ( 100 , 100 , 50 , { 255 , 0 , 0 } ) |&gt; CImg . display ( )","ref":"CImg.html#display/1","title":"CImg.display/1","type":"function"},{"doc":"{crop} Display the image on the CImgDisplay object. Parameters cimg - %CImg{} or %Builder{} display - CImgDisplay object Examples disp = CImgDisplay . create ( img , &quot;Sample&quot; ) CImg . display ( img , disp )","ref":"CImg.html#display/2","title":"CImg.display/2","type":"function"},{"doc":"{crop} Display the image on the Livebook. Parameters img - %CImg{} or %Builder{} mime_type - image file format: :jpeg , :png Examples CImg . builder ( :file , &quot;sample.jpg&quot; ) |&gt; CImg . display_kino ( :jpeg )","ref":"CImg.html#display_kino/2","title":"CImg.display_kino/2","type":"function"},{"doc":"{grow} Booking to draw filled circle in the image. Parameters builder - %Builder{} x0,y0 - circle center location radius - circle radius color - filling color opacity - opacity: 0.0-1.0 Examples result = CImg . builder ( cimg ) |&gt; CImg . draw_circle ( imge , 100 , 80 , 40 , { 0 , 0 , 255 } ) |&gt; CImg . run ( )","ref":"CImg.html#draw_circle/6","title":"CImg.draw_circle/6","type":"function"},{"doc":"{grow} Booking to draw circle in the image. Parameters builder - %Builder{} x0,y0 - circle center location radius - circle radius color - boundary color opacity - opacity: 0.0-1.0 pattern - boundary line pattern Examples result = CImg.builder(cimg) |&gt; CImg.draw_circle(imge, 100, 80, 40, {0, 0, 255}, 0.3, 0xFFFFFFFF) |&gt; CImg.run()","ref":"CImg.html#draw_circle/7","title":"CImg.draw_circle/7","type":"function"},{"doc":"{grow} Booking to draw graph. Parameters builder - %Builder{} data - plot data (%CImg{}) color - RGB color tuple: {R,G,B} where 0 竕ｦ R,G,B 竕ｦ 255 opacity - plot_type - 0 = No plot. 1 = Plot using segments. 2 = Plot using cubic splines. 3 = Plot with bars. vertex_type - 0 = No points. 1 = Point. 2 = Straight cross. 3 = Diagonal cross. 4 = Filled circle. 5 = Outlined circle. 6 = Square. 7 = Diamond. ymin, ymax - lower and upper bound of the y-range pattern - line style Examples CImg . builder ( screen ) |&gt; CImg . draw_graph ( CImg . get_crop ( image , 0 , y , 0 , 0 , width - 1 , y , 0 , 0 ) , red , 1.0 , 1 , 0 , 255.0 , 0.0 ) |&gt; CImg . draw_graph ( CImg . get_crop ( image , 0 , y , 0 , 1 , width - 1 , y , 0 , 1 ) , green , 1.0 , 1 , 0 , 255.0 , 0.0 ) |&gt; CImg . draw_graph ( CImg . get_crop ( image , 0 , y , 0 , 2 , width - 1 , y , 0 , 2 ) , blue , 1.0 , 1 , 0 , 255.0 , 0.0 ) |&gt; CImg . display ( draw_disp )","ref":"CImg.html#draw_graph/9","title":"CImg.draw_graph/9","type":"function"},{"doc":"[grow] Booking to draw line in the image. Parameters builder - %Builder{} x1,y1,x2,y2 - ends of the line. if all of them are integer, they mean actual coodinates. if all of them are float, they mean ratio of the image. color - line color opts thick: val - thick of line opacity: val - opacity: 0.0-1.0 pattern: val - boundary line pattern: 32bit pattern Examples CImg . builder ( img ) |&gt; CImg . draw_line ( 10 , 10 , 20 , 30 , :white , thick : 3 )","ref":"CImg.html#draw_line/7","title":"CImg.draw_line/7","type":"function"},{"doc":"[grow] Booking to draw marker. Parameters builder - %Builder{} x,y - location. if all of them are integer, they mean actual coodinates. if all of them are float, they mean ratio of the image. color - marker color opts size - size of marker (&gt;= 0) mark - shape of marker (only :circle is avalable now)","ref":"CImg.html#draw_marker/5","title":"CImg.draw_marker/5","type":"function"},{"doc":"{grow} Booking to move pixels on the image according to the mapping table. Parameters img - %CImg{} or %Builder{} mapping - mapping table. ex) [{[10,10],[10,20]}], move pixel at [10,10] to [10,20] cx, cy, cz - location of upper-left mapping table on both images. Examples map = [ { [ 20 , 20 ] , [ 25 , 25 ] } , { [ 20 , 21 ] , [ 25 , 26 ] } ] result = CImg . builder ( :jpeg , &quot;sample.jpg&quot; ) |&gt; CImg . draw_morph ( map ) |&gt; CImg . run ( )","ref":"CImg.html#draw_morph/5","title":"CImg.draw_morph/5","type":"function"},{"doc":"{grow} Booking to draw rectangle in the image. Parameters builder - %Builder{} x0,y0,x1,y1 - diagonal coordinates. if all of them are integer, they mean actual coodinates. if all of them are float within 0.0-1.0, they mean ratio of the image. color - boundary color opacity - opacity: 0.0-1.0 pattern - boundary line pattern: 32bit pattern Examples CImg . builder ( cimg ) |&gt; CImg . draw_rect ( img , 50 , 30 , 100 , 80 , { 255 , 0 , 0 } , 0.3 , 0xFF00FF00 ) |&gt; CImg . display ( ) CImg . builder ( cimg ) |&gt; CImg . draw_rect ( img , 0.2 , 0.3 , 0.6 , 0.8 , { 0 , 255 , 0 } ) |&gt; CImg . display ( )","ref":"CImg.html#draw_rect/8","title":"CImg.draw_rect/8","type":"function"},{"doc":"{grow} Draw text in th image. Parameters builder - %Builder{} x,y - position on the image where the text will begin to be drawn. text - the text to be drawn. font_height - font height in pixels. fg_color - foreground color. choose one of the following: :white , :sliver , :gray , :black , :red , :maroon , :yellow , :olive , :lime , :green , :aqua , :teal , :blue , :navy , :fuchsia , :purple , :transparent bg_color - background color. opacity - opacity: 0.0..1.0. Examples result = CImg . draw_text ( builder , 10 , 20 , &quot;Hello world!&quot; , 32 , :white )","ref":"CImg.html#draw_text/8","title":"CImg.draw_text/8","type":"function"},{"doc":"{grow} Booking to fill the image with val . Parameters builder - %Builder{} val - filling value. Examples result = CImg.builder(cimg) |&gt; CImg.fill(img, 0x7f) |&gt; CImg.run()","ref":"CImg.html#fill/2","title":"CImg.fill/2","type":"function"},{"doc":"{grow} Booking to draw filled circle in the image. Parameters builder - %Builder{} x0,y0 - circle center location radius - circle radius color - filling color opacity - opacity: 0.0-1.0 pattern - boundary line pattern Examples result = CImg . builder ( cimg ) |&gt; CImg . fill_circle ( imge , 100 , 80 , 40 , { 0 , 0 , 255 } , 0xF0F0F0F0 ) |&gt; CImg . run ( )","ref":"CImg.html#fill_circle/7","title":"CImg.fill_circle/7","type":"function"},{"doc":"{grow} Booking to draw filled rectangle in the image. Parameters builder - %Builder{} x0,y0,x1,y1 - diagonal coordinates. if all of them are integer, they mean actual coodinates. if all of them are float within 0.0-1.0, they mean ratio of the image. color - boundary color opacity - opacity: 0.0-1.0 Examples CImg . builder ( cimg ) |&gt; CImg . fill_rect ( img , 50 , 30 , 100 , 80 , { 255 , 0 , 0 } , 0.3 ) |&gt; CImg . display ( ) CImg . builder ( cimg ) |&gt; CImg . fill_rect ( img , 0.2 , 0.3 , 0.6 , 0.8 , { 0 , 255 , 0 } ) |&gt; CImg . display ( )","ref":"CImg.html#fill_rect/8","title":"CImg.fill_rect/8","type":"function"},{"doc":"Create a image from jpeg/png format binary. You can create an image from loaded binary of the JPEG/PNG file. Parameters jpeg_or_png - loaded binary of the image file. Examples bin = File . read! ( &quot;sample.jpg&quot; ) jpeg = CImg . from_binary ( bin )","ref":"CImg.html#from_binary/1","title":"CImg.from_binary/1","type":"function"},{"doc":"Create image{x,y,z,c} from raw binary. from_binary helps you to make the image from the serialiezed output tensor of DNN model. Parameters bin - raw binary data to have in a image. x,y,z,c - image's x-size, y-size, z-size and spectrum. opts - convertion options { :dtype, xxx } - convert data type to pixel. available: &quot;&lt;f4&quot;/32-bit-float, &quot;&lt;u1&quot;/8bit-unsigned-char { :range, {lo, hi} } - convert range lo..hi to 0..255. default range: {0.0, 1.0} { :gauss, {{mu-R,sigma-R},{mu-G,sigma-G},{mu-B,sigma-B}} } - inverse normalization by Gaussian distribution. :nchw - transform axes NCHW to NHWC. :bgt - convert color BGR -&gt; RGB. Examples bin = TflInterp . get_output_tensor ( __MODULE__ , 0 ) img = CImg . from_binary ( bin , 300 , 300 , 1 , 3 , dtype : &quot;&lt;f4&quot; ) img = CImg . from_binary ( bin , 300 , 300 , 1 , 3 , gauss : { { 103.53 , 57.375 } , { 116.28 , 57.12 } , { 123.675 , 58.395 } } )","ref":"CImg.html#from_binary/6","title":"CImg.from_binary/6","type":"function"},{"doc":"Create the image from %Npy{} format data. Parameters npy - %Npy{} has 3 rank. Examples { :ok , npy } = Npy . load ( &quot;image.npy&quot; ) img = CImg . from_npy ( npy )","ref":"CImg.html#from_npy/1","title":"CImg.from_npy/1","type":"function"},{"doc":"{crop} Get the pixel value at (x, y). Parameters img - %CImg{} or %Builder{} x,y,z,c - location in the image. Examples val = CImg . get ( img , 120 , 40 )","ref":"CImg.html#get/5","title":"CImg.get/5","type":"function"},{"doc":"{crop} Extracting a partial image specified in a window from an image. Parameters img - %CImg{} or %Builder{} x0,y0,z0,c0, x1,y1,z1,c1 - window bundary_condition - Examples partial = CImg . get_crop ( img , 100 , 100 , 0 , 0 , 400 , 600 , 0 , 3 )","ref":"CImg.html#get_crop/10","title":"CImg.get_crop/10","type":"function"},{"doc":"{grow} Get the gray image of the image. Parameters img - %CImg{} or %Builder{} opt_pn - intensity inversion: 0 (default) - no-inversion, 1 - inversion Examples gray = CImg . gray ( img )","ref":"CImg.html#gray/2","title":"CImg.gray/2","type":"function"},{"doc":"{grow} Get the inverted image of the image. Examples inv = CImg . invert ( img ) # get inverted image","ref":"CImg.html#invert/1","title":"CImg.invert/1","type":"function"},{"doc":"Load a image from file. The file types supported by this function are jpeg, ping and bmp. The file extension identifies which file type it is. Parameters fname - file path of the image. Examples img = CImg . load ( &quot;sample.jpg&quot; )","ref":"CImg.html#load/1","title":"CImg.load/1","type":"function"},{"doc":"{grow} mirroring the image on axis Parameters img - %CImg{} or %Builder{} axis - flipping axis: :x, :y Examples mirror = CImg . mirror ( img , :y ) # vertical flipping","ref":"CImg.html#mirror/2","title":"CImg.mirror/2","type":"function"},{"doc":"{grow} Paint mask image. Parameters img - %CImg{} or %Builder{} object. mask - %CImg{} object, binary image. lut - color map. opacity - opacity: (1.0-opacity) img + opacity mask Examples img = CImg.paint_mask(img_org, img_mask, [{255,0,0}], 0.6)","ref":"CImg.html#paint_mask/4","title":"CImg.paint_mask/4","type":"function"},{"doc":"{grow} Get a new image object resized {x, y}. Parameters cimg - image object. {x, y} - resize width and height or scale - resize scale align - alignment mode :none - fit resizing :ul - fixed aspect resizing, upper-leftt alignment. :br - fixed aspect resizing, bottom-right alignment. fill - filling value for the margins, when fixed aspect resizing. Examples img = CImg . load ( &quot;sample.jpg&quot; ) result = CImg . get_resize ( img , { 300 , 300 } , :ul )","ref":"CImg.html#resize/4","title":"CImg.resize/4","type":"function"},{"doc":"{crop} Returns an image with the script applied to the seed image. Parameters builder - %Builder{} Examples result = CImg . builder ( 100 , 100 , 1 , 3 , 0 ) |&gt; CImg . draw_circle ( 100 , 100 , 30 , { 0 , 255 , 0 } ) |&gt; CImg . run ( )","ref":"CImg.html#run/1","title":"CImg.run/1","type":"function"},{"doc":"{crop} Returns an image with the script applied to cimg . Parameters builder - %Builder{} cimg - %CImg{} Examples cimg = CImg . load ( &quot;sample.jpg&quot; ) result = CImg . builder ( ) |&gt; CImg . draw_circle ( 100 , 100 , 30 , { 0 , 255 , 0 } ) |&gt; CImg . runit ( cimg )","ref":"CImg.html#run/2","title":"CImg.run/2","type":"function"},{"doc":"{crop} Save the image to the file. Parameters img - %CImg{} or %Builder{} fname - file path for the image. (only jpeg images - xxx.jpg - are available now) Examples CImg . save ( img , &quot;sample.jpg&quot; )","ref":"CImg.html#save/2","title":"CImg.save/2","type":"function"},{"doc":"{grow} Set the pixel value at (x, y). Parameters builder - %Builder{} val - value. x,y,z,c - location in the image. Examples result = CImg . builder ( cimg ) |&gt; CImg . set ( 0x7f , 120 , 40 ) |&gt; CImg . run ( )","ref":"CImg.html#set/6","title":"CImg.set/6","type":"function"},{"doc":"{crop} Get shape {x,y,z,c} of the image Parameters img - %CImg{} or %Builder{} Examples shape = CImg . shape ( img )","ref":"CImg.html#shape/1","title":"CImg.shape/1","type":"function"},{"doc":"{crop} Get byte size of the image Parameters img - %CImg{} or %Builder{} Examples size = CImg . size ( img )","ref":"CImg.html#size/1","title":"CImg.size/1","type":"function"},{"doc":"{grow} Thresholding the image. Parameters img - %CImg{} or %Builder{} object. val - threshold value soft - strict - Examples res = CImg.threshold(img, 100)","ref":"CImg.html#threshold/4","title":"CImg.threshold/4","type":"function"},{"doc":"{crop} Get serialized binary of the image from top-left to bottom-right. to_binary/2 helps you to make 32bit-float arrary for the input tensors of DNN model or jpeg/png format binary on memory. Parameters img - %CImg{} or %Builder{} opts - conversion options :jpeg - convert to JPEG format binary. :png - convert to PNG format binary. following options can be applied when converting the image to row binary. { :dtype, xx } - convert pixel value to data type. available: &quot;&lt;f4&quot;/32bit-float, &quot;&lt;u1&quot;/8bit-unsigned-char { :range, {lo, hi} } - range transformation when :dtype is &quot;&lt;f4&quot;. default range: {0.0, 1.0} { :gauss, {{mu-R,sigma-R},{mu-G,sigma-G},{mu-B,sigma-B}} } - normalize by Gaussian distribution. :nchw - transform axes NHWC to NCHW. :bgr - convert color RGB -&gt; BGR. Examples img = CImg . load ( &quot;sample.jpg&quot; ) jpeg = CImg . to_binary ( img , :jpeg ) # convert to JPEG format binary on memory. png = CImg . to_binary ( img , :png ) # convert to PNG format binary on memory. bin1 = CImg . to_binary ( img , [ { dtype : &quot;&lt;f4&quot; } , { :range , { - 1.0 , 1.0 } } , :nchw ] ) # convert pixel value to 32bit-float in range -1.0..1.0 and transform axis to NCHW. bin2 = CImg . to_binary ( img , dtype : &quot;&lt;f4&quot; ) # convert pixel value to 32bit-float in range 0.0..1.0. bin3 = CImg . to_binary ( img , gauss : { { 103.53 , 57.375 } , { 116.28 , 57.12 } , { 123.675 , 58.395 } } ) # convert pixel value to 32bit-float normalized by Gaussian destribution: mu-R=103.53, sigma-R=57.375,...","ref":"CImg.html#to_binary/2","title":"CImg.to_binary/2","type":"function"},{"doc":"{crop} Convert the image to %Npy{} format data. Parameters img - %CImg{} or %Builder{} opts - conversion options { :dtype, xx } - convert pixel value to data type. available: &quot;&lt;f4&quot;/32bit-float, &quot;&lt;u1&quot;/8bit-unsigned-char { :range, {lo, hi} } - range transformation when :dtype is &quot;&lt;f4&quot;. default range: {0.0, 1.0} { :gauss, {{mu-R,sigma-R},{mu-G,sigma-G},{mu-B,sigma-B}} } - normalize by Gaussian distribution. :nchw - transform axes NHWC to NCHW. :bgr - convert color RGB -&gt; BGR. Examples img = CImg . load ( &quot;sample.jpg&quot; ) npy1 = img |&gt; CImg . to_npy ( ) npy2 = img |&gt; CImg . to_npy ( [ { dtype : &quot;&lt;f4&quot; } , { :range , { - 1.0 , 1.0 } } , :nchw ] ) # convert pixel value to 32bit-float in range -1.0..1.0 and transform axis to NCHW.","ref":"CImg.html#to_npy/2","title":"CImg.to_npy/2","type":"function"},{"doc":"{grow} transpose the image Parameters img - %CImg{} or %Builder{} Examples transposed = CImg . transpose ( img )","ref":"CImg.html#transpose/1","title":"CImg.transpose/1","type":"function"},{"doc":"Record the image processing sequence for SESSION execution.","ref":"CImg.Builder.html","title":"CImg.Builder","type":"module"},{"doc":"CImg utility library.","ref":"CImg.Util.html","title":"CImg.Util","type":"module"},{"doc":"Get aspect of the image. Parameters img - %CImg{}","ref":"CImg.Util.html#aspect/1","title":"CImg.Util.aspect/1","type":"function"},{"doc":"Get inverse aspect of the image. Parameters img - %CImg{}","ref":"CImg.Util.html#inv_aspect/1","title":"CImg.Util.inv_aspect/1","type":"function"},{"doc":"[util] Get a rondom color.","ref":"CImg.Util.html#rand_color/0","title":"CImg.Util.rand_color/0","type":"function"},{"doc":"[util] Make random color palette %{}. Parameters keys - keys of the color palette if keys is integer -&gt; 0..(keys-1) if keys is binary -&gt; read from the file &quot;keys&quot; if keys is list -&gt; use it","ref":"CImg.Util.html#rand_palette/1","title":"CImg.Util.rand_palette/1","type":"function"},{"doc":"Display the CImg objects on PC screen. This module also provides the functionality to handle mouse-event, key-board-event, window-close-event, timer-event etc. Note: You can only use these features in :dev or :test mode.","ref":"CImgDisplay.html","title":"CImgDisplay","type":"module"},{"doc":"See CImg.NIF.cimgdisplay_button/1 .","ref":"CImgDisplay.html#button/1","title":"CImgDisplay.button/1","type":"function"},{"doc":"Create display object. Parameters Examples iex&gt; img = CImg.load(&quot;sample.jpg&quot;) iex&gt; display = CImgDisplay(img, &quot;Sample image&quot;) iex&gt;","ref":"CImgDisplay.html#create/5","title":"CImgDisplay.create/5","type":"function"},{"doc":"See CImg.NIF.cimgdisplay_is_closed/1 .","ref":"CImgDisplay.html#is_closed/1","title":"CImgDisplay.is_closed/1","type":"function"},{"doc":"See CImg.NIF.cimgdisplay_mouse_y/1 .","ref":"CImgDisplay.html#mouse_y/1","title":"CImgDisplay.mouse_y/1","type":"function"},{"doc":"See CImg.NIF.cimgdisplay_wait/1 .","ref":"CImgDisplay.html#wait/1","title":"CImgDisplay.wait/1","type":"function"},{"doc":"See CImg.NIF.cimgdisplay_wait_time/2 .","ref":"CImgDisplay.html#wait/2","title":"CImgDisplay.wait/2","type":"function"},{"doc":"A lightweight image processing module in Elixir using CImg, aimed at creating auxiliary routines for Deep Learning. Note: Only a few image processing functions are available yet.","ref":"readme.html","title":"cimg_ex","type":"extras"},{"doc":"Image data handled by CImg is placed on the NIF side. On the Elixir side, image processing is performed through RESOURCE of images - generated by NIF - stored in the %CImg{} structure. You cannot directly read or process pixels in an image. Instead, you must use the image processing functions provided by the CImg module. Images are automatically subject to garbage collection when they are no longer used. The NIFs RESOURCE management mechanism is used to achieve this functionality. Each function provided by CImg can be used alone or as a set of functions. In the latter case, a seed image is first prepared using CImg.builder/1 or similar, and then a series of functions are put together using Elixir's pipe syntax.","ref":"readme.html#design-detail","title":"cimg_ex - Design detail","type":"extras"},{"doc":"I have confirmed it works in the following OS environment. Windows MSYS2/MinGW64 WSL2/Ubuntu 20.04, 18.04 Linux Mint 20 &quot;Ulyana&quot; Nerves rpi","ref":"readme.html#platform","title":"cimg_ex - Platform","type":"extras"},{"doc":"python3 is required to build this module. In addition, the following libraries are required to display images on a PC screen. GDI32 on Windows X11 on Linux","ref":"readme.html#requirements","title":"cimg_ex - Requirements","type":"extras"},{"doc":"Add following dependency to your mix.exs . def deps do [ { :cimg , &quot;~&gt; 0.1.19&quot; } ] end and install dependencies: $ mix deps.get $ mix deps.compile","ref":"readme.html#installation","title":"cimg_ex - Installation","type":"extras"},{"doc":"A sample program is in the demo directory. You can run it by following the steps below. $ cd demo $ mix deps.get $ mix run -e &quot;CImgDemo.demo1&quot; Closing the application window will stop the demo program. Another demo: $ mix run -e &quot;CImgDemo.demo2&quot; $ mix run -e &quot;CImgDemo.demo3&quot;","ref":"readme.html#demo","title":"cimg_ex - Demo","type":"extras"},{"doc":"The following code is an excerpt of the inference portion from the DeepLab app implemented using TflInterp. CImg preprocesses the input image and passes it through the DeepLab model. And then, the tensor output by DeepLab is transformed by CImg into a colormaedp image. defmodule TflDemo.DeepLab3 do alias TflDemo.DeepLab3.Prediction def apply_deeplab3 ( img_file ) do img = CImg . load ( img_file ) segments = Prediction . apply ( img ) end end defmodule TflDemo.DeepLab3.Prediction do use TflInterp , model : &quot;priv/lite-model_deeplabv3_1_metadata_2.tflite&quot; @deeplab3_shape { 257 , 257 } def apply ( img ) do # preprocess bin = img |&gt; CImg . resize ( @deeplab3_shape ) |&gt; CImg . to_binary ( range : { - 1.0 , 1.0 } ) # prediction outputs = __MODULE__ |&gt; TflInterp . set_input_tensor ( 0 , bin ) |&gt; TflInterp . invoke ( ) |&gt; TflInterp . get_output_tensor ( 0 ) |&gt; Nx . from_binary ( { :f , 32 } ) |&gt; Nx . reshape ( { 257 , 257 , :auto } ) # postprocess outputs |&gt; Nx . argmax ( axis : 2 ) |&gt; Nx . as_type ( { :u , 8 } ) |&gt; Nx . to_binary ( ) |&gt; CImg . from_binary ( 257 , 257 , 1 , 1 , &quot;&lt;u1&quot; ) |&gt; CImg . color_mapping ( :lines ) # convert into a colormaped image end end","ref":"readme.html#example-deep-labelling-for-semantic-image-segmentation","title":"cimg_ex - Example: Deep Labelling for Semantic Image Segmentation","type":"extras"},{"doc":"cimg_ex is licensed under the Apache License Version 2.0. -- license overview of included 3rd party libraries -- The &quot;CImg&quot; Library is licensed under the CeCILL-C/CeCILL. The &quot;stb&quot; - single-file public domain libraries for C/C++ - is public domain or MIT licensed.","ref":"readme.html#license","title":"cimg_ex - License","type":"extras"},{"doc":"","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"Major Features and Improvements add &quot;append/4&quot;.","ref":"changelog.html#release-0-1-19","title":"Changelog - Release 0.1.19","type":"extras"},{"doc":"Major Features and Improvements add &quot;paint_mask/4&quot;.","ref":"changelog.html#release-0-1-18","title":"Changelog - Release 0.1.18","type":"extras"},{"doc":"Major Features and Improvements add &quot;draw_marker/5&quot;.","ref":"changelog.html#release-0-1-17","title":"Changelog - Release 0.1.17","type":"extras"},{"doc":"Major Features and Improvements support dtype: &quot;&lt;i4&quot; in to_binary/2.","ref":"changelog.html#release-0-1-16","title":"Changelog - Release 0.1.16","type":"extras"},{"doc":"Major Features and Improvements added &quot;draw_line&quot;","ref":"changelog.html#release-0-1-15","title":"Changelog - Release 0.1.15","type":"extras"},{"doc":"Major Features and Improvements added &quot;fill_rect&quot; and &quot;fill_circle&quot;. added CImg.Util module including 'aspect' and 'rand_palette'.","ref":"changelog.html#release-0-1-14","title":"Changelog - Release 0.1.14","type":"extras"},{"doc":"Major Features and Improvements added Gaussian distribution transformation to to_binary/e2 and from_binary/6 . Bug Fixes and Other Changes fixed a bug of inverse range conversion of from_binary/6.","ref":"changelog.html#release-0-1-13","title":"Changelog - Release 0.1.13","type":"extras"},{"doc":"Major Features and Improvements add image blending operation blend/3 . Bug Fixes and Other Changes revised Makefile for possible to build for Nerves devices on MacOS. (PR#1)","ref":"changelog.html#release-0-1-12","title":"Changelog - Release 0.1.12","type":"extras"},{"doc":"Major Features and Improvements add convertion options to from_binary/6 . Bug Fixes and Other Changes correct document.","ref":"changelog.html#release-0-1-11","title":"Changelog - Release 0.1.11","type":"extras"},{"doc":"Breaking Changes remove deprecated functions. see Release 0.1.7 changelog. remove Builder.from_binary/1, Builder.resize/4. replaced by session. Major Features and Improvements add session execution mode. add CImg.display_kino/2. Bug Fixes and Other Changes fixed a bug that did not release image resources.","ref":"changelog.html#release-0-1-10","title":"Changelog - Release 0.1.10","type":"extras"},{"doc":"Major Features and Improvements add draw_text/8. add Builder.from_binary/1, enable Builder.resize/4 (experimental)","ref":"changelog.html#release-0-1-9","title":"Changelog - Release 0.1.9","type":"extras"},{"doc":"Major Features and Improvements supported Nerves/rpi. resize/4 accepts resize scale instead {x, y}. Bug Fixes and Other Changes corrected argument checking of color_mapping/2 . replace CImg download script with 'git clone'.","ref":"changelog.html#release-0-1-8","title":"Changelog - Release 0.1.8","type":"extras"},{"doc":"Breaking Changes deprecated: to_jpeg/1 , to_png/1 , to_flat/2 . Use to_binary/2 instead. deprecated: create_from_bin/6 . Use from_binary/6 instead. deprecated: load_from_memory/1 . Use from_binary/1 instead. Major Features and Improvements add integrated converter from a image to a binary: to_binary/2 . add color mapping: color_mapping/2 . rename create_from_bin/6 to from_binary/6 . rename load_from_memory/1 to from_binary/1 . to_npy/2 takes various conversion modes as optional parameters. Bug Fixes and Other Changes correct an axis order of shape in from_npy/1 , to_npy/2 .","ref":"changelog.html#release-0-1-7","title":"Changelog - Release 0.1.7","type":"extras"},{"doc":"Major Features and Improvements add image convertor to_jpeg/1 , to_png/1 (experimental)","ref":"changelog.html#release-0-1-6-jan-06-2022","title":"Changelog - Release 0.1.6 (Jan 06 2022)","type":"extras"}]